( cd opt/kde/share/doc/HTML/en/kmag ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kmag ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kmousetool ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kmousetool ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kmouth ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kmouth ; ln -sf /opt/kde/share/doc/HTML/en/common common )
